@@ -40,11 +40,9 @@ These are common 2D params, kwargs are frame specific
 two_D_parameters = [
     ([0 * u.deg, 0 * u.arcsec], None),
     ([0 * u.deg, 0 * u.arcsec], {'obstime': '2011/01/01T00:00:00'}),
-    ([0 * u.deg, 0 * u.arcsec], {'representation_type': 'unitspherical'}),
     ([UnitSphericalRepresentation(0 * u.deg, 0 * u.arcsec)], None),
-    ([UnitSphericalRepresentation(0 * u.deg, 0 * u.arcsec)], None), (
-        [UnitSphericalRepresentation(0 * u.deg, 0 * u.arcsec)],
-        {'obstime': '2011/01/01T00:00:00'})
+    ([UnitSphericalRepresentation(0 * u.deg, 0 * u.arcsec)], {'obstime': '2011/01/01T00:00:00'}),
+    ([0 * u.deg, 0 * u.arcsec], {'representation_type': 'unitspherical'})
 ]
 """
 These are common 3D params, kwargs are frame specific
@@ -143,7 +141,7 @@ def test_hpc_distance():
     assert hpc1.Tx == 0 * u.arcsec
     assert hpc1.Ty == 0 * u.arcsec
 
-    hpc2 = hpc1.calculate_distance()
+    hpc2 = hpc1.make_3d()
 
     assert isinstance(hpc2._data, SphericalRepresentation)
 
@@ -160,7 +158,7 @@ def test_hpc_distance_cartesian():
     assert isinstance(hpc1, Helioprojective)
     assert isinstance(hpc1._data, CartesianRepresentation)
 
-    assert hpc1.calculate_distance() is hpc1
+    assert hpc1.make_3d() is hpc1
 
 
 def test_hpc_distance_off_limb():
@@ -175,7 +173,7 @@ def test_hpc_distance_off_limb():
     assert hpc1.Tx == 1500 * u.arcsec
     assert hpc1.Ty == 0 * u.arcsec
 
-    hpc2 = hpc1.calculate_distance()
+    hpc2 = hpc1.make_3d()
 
     assert isinstance(hpc2._data, SphericalRepresentation)
 
@@ -196,7 +194,7 @@ def test_hpc_distance_3D():
     assert hpc1.Tx == 1500 * u.arcsec
     assert hpc1.Ty == 0 * u.arcsec
 
-    hpc2 = hpc1.calculate_distance()
+    hpc2 = hpc1.make_3d()
 
     assert hpc2 is hpc1
 
@@ -238,7 +236,7 @@ def test_HEE_creation():
 
 @pytest.mark.parametrize('frame',
                          [HeliographicStonyhurst, HeliographicCarrington])
-@pytest.mark.parametrize("args, kwargs", two_D_parameters[:2] + two_D_parameters[4:] +
+@pytest.mark.parametrize("args, kwargs", two_D_parameters[:4] +
                          [(None, {'lat': 0*u.deg, 'lon': 0*u.arcsec})])
 def test_create_hgs_2d(frame, args, kwargs):
     hgs1 = init_frame(frame, args, kwargs)
@@ -265,7 +263,7 @@ def test_create_hgs_2d(frame, args, kwargs):
 
 @pytest.mark.parametrize('frame',
                          [HeliographicStonyhurst, HeliographicCarrington])
-@pytest.mark.parametrize("args, kwargs", two_D_parameters[2:4])
+@pytest.mark.parametrize("args, kwargs", two_D_parameters[4:])
 def test_create_hgs_force_2d(frame, args, kwargs):
     hgs1 = init_frame(frame, args, kwargs)
 
@@ -274,8 +272,7 @@ def test_create_hgs_force_2d(frame, args, kwargs):
 
     rep_kwarg = kwargs.get('representation_type', None) if kwargs else None
 
-    if rep_kwarg == 'unitspherical':
-        assert isinstance(hgs1._data, UnitSphericalRepresentation)
+    assert not hasattr(hgs1, 'radius')
 
     # Check the attrs are correct
     assert hgs1.lon == 0 * u.deg
@@ -394,6 +391,8 @@ def test_hcc_default_observer():
 
 two_D_parameters = [
     ([0 * u.deg, 0 * u.arcsec], {}),
+    ([[0, 1, 2, 3], [5, 6, 7, 8]], {'unit': u.deg}),
+    ([0 * u.deg, 0 * u.arcsec], {'representation_type': SphericalRepresentation}),
     ([UnitSphericalRepresentation(0 * u.deg, 0 * u.arcsec)], {}),
     ([UnitSphericalRepresentation(0 * u.deg, 0 * u.arcsec)], {}),
     ([SphericalRepresentation(0 * u.deg, 0 * u.arcsec, 1*u.one)], {}),
@@ -405,12 +404,13 @@ two_D_parameters = [
                                               {'representation_type': 'unitspherical'})])
 def test_skycoord_hpc(args, kwargs):
     """
-    Test that when instantiating a HPC frame with SkyCoord calculate distance
+    Test that when instantiating a HPC frame with SkyCoord that make_3d
     still works.
     """
 
-    sc = SkyCoord(*args, **kwargs, frame="helioprojective", obstime="2011-01-01T00:00:00")
-    # Test the transform to HGS because it will force a `calculate_distance` call.
+    sc = SkyCoord(*args, **kwargs, frame="helioprojective",
+                  observer='earth', obstime="2011-01-01T00:00:00")
+    # Test the transform to HGS because it will force a `make_3d` call.
     hgs = sc.transform_to("heliographic_stonyhurst")
 
     assert isinstance(hgs.frame, HeliographicStonyhurst)
@@ -419,7 +419,7 @@ def test_skycoord_hpc(args, kwargs):
 @pytest.mark.parametrize("args, kwargs", two_D_parameters)
 def test_skycoord_hgs(args, kwargs):
     """
-    Test that when instantiating a HPC frame with SkyCoord correctly replaces
+    Test that when instantiating a HGS frame with SkyCoord correctly replaces
     distance.
 
     Note: We only need to test HGS here not HGC as they share the same
@@ -427,6 +427,9 @@ def test_skycoord_hgs(args, kwargs):
     """
 
     RSUN_METERS = sun.constants.get('radius').si
-    sc = SkyCoord(*args, **kwargs, frame="heliographic_stonyhurst", obstime="2011-01-01T00:00:00")
+    sc = SkyCoord(*args, **kwargs, frame=HeliographicStonyhurst(obstime="2011-01-01T00:00:00"))
 
+    # Check that we have upgraded the data to Spherical
+    assert isinstance(sc.frame._data, SphericalRepresentation)
+    # Check the value is correct
     assert_quantity_allclose(sc.radius, RSUN_METERS)
