@@ -19,8 +19,11 @@ from astropy.time import Time
 
 from sunpy.coordinates import (Helioprojective, HeliographicStonyhurst,
                                HeliographicCarrington, Heliocentric,
+                               HeliocentricEarthEcliptic, GeocentricSolarEcliptic,
+                               HeliocentricInertial, GeocentricEarthEquatorial,
                                get_earth)
 from sunpy.coordinates import sun
+from sunpy.coordinates.frames import _J2000
 from sunpy.time import parse_time
 
 
@@ -180,10 +183,11 @@ def test_hgs_cartesian_rep_to_hpc():
     hgscoord_cart = SkyCoord(x=1*u.km, y=0.*u.km, z=0.*u.km,
                              frame=HeliographicStonyhurst(obstime=obstime),
                              representation_type='cartesian')
+    hpc_frame = Helioprojective(observer='earth', obstime=obstime)
     hgscoord_sph = hgscoord_cart.copy()
     hgscoord_sph.representation_type = 'spherical'
-    hpccoord_cart = hgscoord_cart.transform_to(Helioprojective(obstime=obstime))
-    hpccoord_sph = hgscoord_sph.transform_to(Helioprojective(obstime=obstime))
+    hpccoord_cart = hgscoord_cart.transform_to(hpc_frame)
+    hpccoord_sph = hgscoord_sph.transform_to(hpc_frame)
     assert_quantity_allclose(hpccoord_cart.Tx, hpccoord_sph.Tx)
     assert_quantity_allclose(hpccoord_cart.Ty, hpccoord_sph.Ty)
     assert_quantity_allclose(hpccoord_cart.distance, hpccoord_sph.distance)
@@ -198,10 +202,11 @@ def test_hgs_cartesian_rep_to_hcc():
     hgscoord_cart = SkyCoord(x=1*u.km, y=0.*u.km, z=0.*u.km,
                              frame=HeliographicStonyhurst(obstime=obstime),
                              representation_type='cartesian')
+    hcc_frame = Heliocentric(observer='earth', obstime=obstime)
     hgscoord_sph = hgscoord_cart.copy()
     hgscoord_sph.representation_type = 'spherical'
-    hcccoord_cart = hgscoord_cart.transform_to(Heliocentric(obstime=obstime))
-    hcccoord_sph = hgscoord_sph.transform_to(Heliocentric(obstime=obstime))
+    hcccoord_cart = hgscoord_cart.transform_to(hcc_frame)
+    hcccoord_sph = hgscoord_sph.transform_to(hcc_frame)
     assert_quantity_allclose(hcccoord_cart.x, hcccoord_sph.x)
     assert_quantity_allclose(hcccoord_cart.y, hcccoord_sph.y)
     assert_quantity_allclose(hcccoord_cart.z, hcccoord_sph.z)
@@ -448,7 +453,7 @@ def test_hgs_hcc_sunspice():
 
     old = SkyCoord(CartesianRepresentation([7e5, 8e5, 9e5]*u.km),
                    frame=HeliographicStonyhurst(obstime='2019-06-01'))
-    new = old.heliocentric
+    new = old.transform_to(Heliocentric(observer='earth'))
 
     assert_quantity_allclose(new.x, 800000.00*u.km, atol=1e-2*u.km)
     assert_quantity_allclose(new.y, 908797.89*u.km, atol=1e-2*u.km)
@@ -464,9 +469,9 @@ def test_hpc_hgs_implicit_hcc():
 
     implicit = start.transform_to(frame)
     explicit1 = start.transform_to(Heliocentric(obstime=start.obstime, observer='earth')).\
-                      transform_to(frame)
+        transform_to(frame)
     explicit2 = start.transform_to(Heliocentric(obstime=frame.obstime, observer='earth')).\
-                      transform_to(frame)
+        transform_to(frame)
 
     assert_quantity_allclose(implicit.separation_3d(explicit1), 0*u.AU, atol=1e-10*u.AU)
     assert_quantity_allclose(implicit.separation_3d(explicit2), 0*u.AU, atol=1e-10*u.AU)
@@ -509,3 +514,221 @@ def test_velocity_hgs_hgc():
     assert_quantity_allclose(new_vel.d_lon, -360*u.deg / (27.27253*u.day), rtol=1e-2)
     assert_quantity_allclose(new_vel.d_lat, 0*u.deg/u.s)
     assert_quantity_allclose(new_vel.d_distance, 0*u.km/u.s, atol=1e-7*u.km/u.s)
+
+
+def test_hme_hee_sunspice():
+    # Compare our HME->HEE transformation against SunSPICE
+    # "HAE" is equivalent to Astropy's Heliocentric Mean Ecliptic, and defaults to J2000.0
+    #
+    # IDL> coord = [1.d, 0.d, 10.d]
+    # IDL> convert_sunspice_lonlat, '2019-06-01', coord, 'HAE', 'HEE', /au, /degrees
+    # IDL> print, coord
+    #        1.0000000       110.01610       10.000300
+
+    old = SkyCoord(0*u.deg, 10*u.deg, 1*u.AU, frame=HeliocentricMeanEcliptic(obstime='2019-06-01'))
+    new = old.transform_to(HeliocentricEarthEcliptic)
+
+    assert_quantity_allclose(new.lon, Longitude(110.01610*u.deg), atol=0.01*u.arcsec, rtol=0)
+    assert_quantity_allclose(new.lat, 10.000300*u.deg, atol=0.01*u.arcsec, rtol=0)
+    assert_quantity_allclose(new.distance, old.distance)
+
+    # Transform from HAE precessed to the mean ecliptic of date instead of J2000.0
+    # IDL> coord = [1.d, 0.d, 10.d]
+    # IDL> convert_sunspice_lonlat, '2019-06-01', coord, 'HAE', 'HEE', /au, /degrees, /precess
+    # IDL> print, coord
+    #        1.0000000       109.74535       10.000070
+
+    old = SkyCoord(0*u.deg, 10*u.deg, 1*u.AU, frame=HeliocentricMeanEcliptic(obstime='2019-06-01',
+                                                                             equinox='2019-06-01'))
+    new = old.transform_to(HeliocentricEarthEcliptic)
+
+    assert_quantity_allclose(new.lon, Longitude(109.74535*u.deg), atol=0.05*u.arcsec, rtol=0)
+    assert_quantity_allclose(new.lat, 10.000070*u.deg, atol=0.01*u.arcsec, rtol=0)
+    assert_quantity_allclose(new.distance, old.distance)
+
+
+def test_hee_hee():
+    # Test HEE loopback transformation
+    obstime = Time('2001-01-01')
+    old = SkyCoord(90*u.deg, 10*u.deg, 1*u.AU, frame=HeliocentricEarthEcliptic(obstime=obstime))
+
+    new = old.transform_to(HeliocentricEarthEcliptic)
+
+    assert_quantity_allclose(new.lon, old.lon)
+    assert_quantity_allclose(new.lat, old.lat)
+    assert_quantity_allclose(new.distance, old.distance)
+
+    new = old.transform_to(HeliocentricEarthEcliptic(obstime=obstime + 1*u.day))
+
+    assert_quantity_allclose(new.lon, old.lon - 1*u.deg, atol=0.1*u.deg)  # due to Earth motion
+    assert_quantity_allclose(new.lat, old.lat, atol=0.5*u.arcsec)
+    assert_quantity_allclose(new.distance, old.distance, rtol=1e-5)
+
+
+def test_hee_gse_sunspice():
+    # Compare our HEE->GSE transformation against SunSPICE
+    #
+    # IDL> coord = [0.7d, -20.d, 10.d]
+    # IDL> convert_sunspice_coord, '2019-06-01', coord, 'HEE', 'GSE', /au, /degrees
+    # IDL> print, coord
+    #       0.45215884       32.777377       15.594639
+
+    old = SkyCoord(-20*u.deg, 10*u.deg, 0.7*u.AU,
+                   frame=HeliocentricEarthEcliptic(obstime='2019-06-01'))
+    new = old.geocentricsolarecliptic
+
+    assert_quantity_allclose(new.lon, 32.777377*u.deg, atol=0.01*u.arcsec, rtol=0)
+    assert_quantity_allclose(new.lat, 15.594639*u.deg, atol=0.01*u.arcsec, rtol=0)
+    assert_quantity_allclose(new.distance, 0.45215884*u.AU)
+
+
+def test_gse_gse():
+    # Test GSE loopback transformation
+    old = SkyCoord(90*u.deg, 10*u.deg, 0.7*u.AU,
+                   frame=GeocentricSolarEcliptic(obstime='2001-01-01'))
+    new = old.transform_to(GeocentricSolarEcliptic)
+
+    assert_quantity_allclose(new.lon, old.lon)
+    assert_quantity_allclose(new.lat, old.lat)
+    assert_quantity_allclose(new.distance, old.distance)
+
+
+def test_hgs_hci_sunspice():
+    # Compare our HGS->HCI transformation against SunSPICE
+    # "HEQ" is another name for HEEQ, which is equivalent to Heliographic Stonyhurst
+    #
+    # IDL> coord = [1.d, 120.d, 10.d]
+    # IDL> convert_sunspice_lonlat, '2019-06-01', coord, 'HEQ', 'HCI', /au, /degrees
+    # IDL> print, coord
+    #        1.0000000      -65.736793       10.000000
+
+    old = SkyCoord(120*u.deg, 10*u.deg, 1*u.AU, frame=HeliographicStonyhurst(obstime='2019-06-01'))
+    new = old.transform_to(HeliocentricInertial)
+
+    assert_quantity_allclose(new.lon, -65.736793*u.deg, atol=0.5*u.arcsec, rtol=0)
+    assert_quantity_allclose(new.lat, old.lat)
+    assert_quantity_allclose(new.distance, old.radius)
+
+
+def test_hci_hci():
+    # Test HCI loopback transformation
+    obstime = Time('2001-01-01')
+    old = SkyCoord(90*u.deg, 10*u.deg, 0.7*u.AU, frame=HeliocentricInertial(obstime=obstime))
+    new = old.transform_to(HeliocentricInertial)
+
+    assert_quantity_allclose(new.lon, old.lon)
+    assert_quantity_allclose(new.lat, old.lat)
+    assert_quantity_allclose(new.distance, old.distance)
+
+    new = old.transform_to(HeliocentricInertial(obstime=obstime + 1*u.day))
+
+    assert_quantity_allclose(new.lon, old.lon, atol=0.1*u.deg)  # due to Earth motion
+    assert_quantity_allclose(new.lat, old.lat, atol=1e-3*u.deg)
+    assert_quantity_allclose(new.distance, old.distance, atol=1e-5*u.AU)
+
+
+def test_hme_gei_sunspice():
+    # Compare our HME->GEI transformation against SunSPICE
+    # "HAE" is equivalent to Astropy's Heliocentric Mean Ecliptic, and defaults to J2000.0
+    #
+    # IDL> coord = [1.d, 120.d, 10.d]
+    # IDL> convert_sunspice_lonlat, '2019-06-01', coord, 'HAE', 'GEI', /au, /degrees
+    # IDL> print, coord
+    #        1.8197210       95.230617       28.830109
+
+    old = SkyCoord(120*u.deg, 10*u.deg, 1*u.AU,
+                   frame=HeliocentricMeanEcliptic(obstime='2019-06-01'))
+    new = old.transform_to(GeocentricEarthEquatorial)
+
+    assert_quantity_allclose(new.lon, Longitude(95.230617*u.deg), atol=0.01*u.arcsec, rtol=0)
+    assert_quantity_allclose(new.lat, 28.830109*u.deg, atol=0.05*u.arcsec, rtol=0)
+    assert_quantity_allclose(new.distance, 1.8197210*u.AU)
+
+    # Transform from HAE precessed to the mean ecliptic of date instead of J2000.0
+    # IDL> coord = [1.d, 120.d, 10.d]
+    # IDL> convert_sunspice_lonlat, '2019-06-01', coord, 'HAE', 'GEI', /au, /degrees, /precess
+    # IDL> print, coord
+    #        1.8217103       95.079030       28.827750
+
+    old = SkyCoord(120*u.deg, 10*u.deg, 1*u.AU,
+                   frame=HeliocentricMeanEcliptic(obstime='2019-06-01', equinox='2019-06-01'))
+    new = old.transform_to(GeocentricEarthEquatorial(equinox=_J2000))
+
+    assert_quantity_allclose(new.lon, Longitude(95.079030*u.deg), atol=0.05*u.arcsec, rtol=0)
+    assert_quantity_allclose(new.lat, 28.827750*u.deg, atol=0.05*u.arcsec, rtol=0)
+    assert_quantity_allclose(new.distance, 1.8217103*u.AU)
+
+
+def test_gei_gei():
+    # Test GEI loopback transformation using the 2017 revision to Franz & Harper 2002
+    t = Time('1996-08-28 16:46:00', scale='tt')
+    gei_j2000 = CartesianRepresentation([-5.7840451, -4.1082375, 1.9146822] * (6378.14*u.km))
+    gei_d = CartesianRepresentation([-5.7864918, -4.1039136, 1.9165612] * (6378.14*u.km))
+
+    old = SkyCoord(gei_j2000, frame=GeocentricEarthEquatorial(obstime=t))
+    new = old.transform_to(GeocentricEarthEquatorial(equinox=t, obstime=t)).cartesian
+
+    assert_quantity_allclose(new.xyz, gei_d.xyz)
+
+
+def test_no_observer():
+    # Tests transformations to and from observer-based frames with no observer defined
+    frames_in = [Heliocentric(0*u.km, 0*u.km, 0*u.km, observer=None),
+                 Heliocentric(0*u.km, 0*u.km, 0*u.km, observer=None, obstime='2001-01-01'),
+                 Helioprojective(0*u.deg, 0*u.deg, observer=None),
+                 Helioprojective(0*u.deg, 0*u.deg, observer=None, obstime='2001-01-01')]
+    frames_out = frames_in + [
+        HeliographicStonyhurst(0*u.deg, 0*u.deg, obstime=None),
+        HeliographicStonyhurst(0*u.deg, 0*u.deg, obstime='2001-01-01'),
+        Heliocentric(0*u.km, 0*u.km, 0*u.km, observer=None, obstime='2012-12-12'),
+        Heliocentric(0*u.km, 0*u.km, 0*u.km, observer="earth", obstime=None),
+        Heliocentric(0*u.km, 0*u.km, 0*u.km, observer="earth", obstime='2001-01-01'),
+        Helioprojective(0*u.deg, 0*u.deg, observer=None, obstime='2012-12-12'),
+        Helioprojective(0*u.deg, 0*u.deg, observer="earth", obstime=None),
+        Helioprojective(0*u.deg, 0*u.deg, observer="earth", obstime='2001-01-01')]
+
+    # Self-transformations should succeed
+    for f in frames_in:
+        f.transform_to(f.replicate_without_data())
+
+    # All other transformations should error
+    for i, f1 in enumerate(frames_in):
+        for f2 in frames_out[i + 1:]:
+            with pytest.raises(ConvertError):
+                f1.transform_to(f2)
+            with pytest.raises(ConvertError):
+                f2.transform_to(f1)
+
+
+def test_array_obstime():
+    # Validate that you can transform from an array of obstimes to no obstimes,
+    # or different obstimes.
+    a = SkyCoord([10]*2, [10]*2, unit=u.deg,
+                 observer="earth",
+                 obstime=["2019-01-01", "2019-01-02"],
+                 frame="heliographic_carrington")
+
+    t = a.transform_to(Helioprojective)
+    assert isinstance(t.frame, Helioprojective)
+
+    t2 = a.transform_to(Helioprojective(obstime=["2019-01-03", "2019-01-04"]))
+    assert isinstance(t2.frame, Helioprojective)
+
+
+_frameset1 = [HeliographicStonyhurst, HeliographicCarrington, HeliocentricInertial]
+_frameset2 = [Heliocentric, Helioprojective]
+
+
+@pytest.mark.parametrize("start_class", _frameset1 + _frameset2)
+@pytest.mark.parametrize("end_class", _frameset1)
+def test_no_obstime_on_one_end(start_class, end_class):
+    start_obstime = Time("2001-01-01")
+
+    if hasattr(start_class, 'observer'):
+        coord = start_class(CartesianRepresentation(0, 0, 0)*u.km,
+                            obstime=start_obstime, observer="earth")
+    else:
+        coord = start_class(CartesianRepresentation(0, 0, 0)*u.km, obstime=start_obstime)
+
+    result = coord.transform_to(end_class)
+    assert result.obstime == start_obstime
