@@ -1,26 +1,25 @@
-import tempfile
 import os.path
-import pytest
 import datetime
+import tempfile
 
 import numpy as np
 import pandas
+import pytest
 
-from astropy.time import TimeDelta
 import astropy.units as u
+from astropy.time import TimeDelta
 
-from sunpy.data.test import rootdir
-from sunpy.time import parse_time, is_time_equal
 from sunpy import timeseries
+from sunpy.data.test import rootdir
 from sunpy.instr import lyra
-
+from sunpy.time import is_time_equal, parse_time
 
 # Define location for test LYTAF database files
 TEST_DATA_PATH = rootdir
 
 # Define some test data for test_remove_lytaf_events()
 TIME = parse_time(np.array([datetime.datetime(2013, 2, 1) + datetime.timedelta(minutes=i)
-                  for i in range(120)]))
+                            for i in range(120)]))
 CHANNELS = [np.zeros(len(TIME)) + 0.4, np.zeros(len(TIME)) + 0.1]
 EMPTY_LYTAF = np.empty((0,), dtype=[("insertion_time", object),
                                     ("begin_time", object),
@@ -48,11 +47,9 @@ LYTAF_TEST = np.append(
 
 @pytest.mark.remote_data
 def test_split_series_using_lytaf():
-    '''test the downloading of the LYTAF file and subsequent queries'''
-    tmp_dir = tempfile.mkdtemp()
-    lyra.download_lytaf_database(lytaf_dir=tmp_dir)
-    assert os.path.exists(os.path.join(tmp_dir, 'annotation_ppt.db'))
-
+    """
+    test the downloading of the LYTAF file and subsequent queries.
+    """
     # test split_series_using_lytaf
     # construct a dummy signal for testing purposes
     basetime = parse_time('2010-06-13 02:00')
@@ -61,7 +58,6 @@ def test_split_series_using_lytaf():
     dummy_data = np.random.random(seconds)
 
     lytaf_tmp = lyra.get_lytaf_events('2010-06-13 02:00', '2010-06-13 06:00',
-                                      lytaf_path=tmp_dir,
                                       combine_files=["ppt"])
     split = lyra.split_series_using_lytaf(dummy_time, dummy_data, lytaf_tmp)
     assert type(split) == list
@@ -97,18 +93,20 @@ def lyra_ts():
 
 @pytest.mark.remote_data
 def test_remove_lytaf_events_from_timeseries(lyra_ts):
-    """Test if artefacts are correctly removed from a TimeSeries."""
+    """
+    Test if artifact are correctly removed from a TimeSeries.
+    """
     # Check correct errors are raised due to bad input
     with pytest.raises(AttributeError):
         ts_test = lyra.remove_lytaf_events_from_timeseries(
-            [], lytaf_path=TEST_DATA_PATH, force_use_local_lytaf=True)
+            [], force_use_local_lytaf=True)
 
     # Run remove_artifacts_from_timeseries, returning artifact
     # status
     ts_test, artifact_status_test = \
         lyra.remove_lytaf_events_from_timeseries(
             lyra_ts, artifacts=["LAR", "Offpoint"], return_artifacts=True,
-            lytaf_path=TEST_DATA_PATH, force_use_local_lytaf=True)
+            force_use_local_lytaf=True)
     # Generate expected data by calling _remove_lytaf_events and
     # constructing expected dataframe manually.
     time, channels, artifact_status_expected = lyra._remove_lytaf_events(
@@ -117,7 +115,7 @@ def test_remove_lytaf_events_from_timeseries(lyra_ts):
                                       np.asanyarray(lyra_ts.data["CHANNEL3"]),
                                       np.asanyarray(lyra_ts.data["CHANNEL4"])],
         artifacts=["LAR", "Offpoint"], return_artifacts=True,
-        lytaf_path=TEST_DATA_PATH, force_use_local_lytaf=True)
+        force_use_local_lytaf=True)
     dataframe_expected = pandas.DataFrame(index=time,
                                           data={"CHANNEL1": channels[0],
                                                 "CHANNEL2": channels[1],
@@ -140,19 +138,33 @@ def test_remove_lytaf_events_from_timeseries(lyra_ts):
     ts_test = \
         lyra.remove_lytaf_events_from_timeseries(
             lyra_ts, artifacts=["LAR", "Offpoint"],
-            lytaf_path=TEST_DATA_PATH, force_use_local_lytaf=True)
+            force_use_local_lytaf=True)
     # Assert expected result is returned
     pandas.util.testing.assert_frame_equal(ts_test.data, dataframe_expected)
 
 
-def test_remove_lytaf_events_1():
-    """Test _remove_lytaf_events() with some artifacts found and others not."""
+@pytest.fixture()
+def local_cache(sunpy_cache):
+    sunpy_cache = sunpy_cache('sunpy.instr.lyra.cache')
+    sunpy_cache.add('http://proba2.oma.be/lyra/data/lytaf/annotation_lyra.db',
+                    os.path.join(TEST_DATA_PATH, 'annotation_lyra.db'))
+    sunpy_cache.add('http://proba2.oma.be/lyra/data/lytaf/annotation_manual.db',
+                    os.path.join(TEST_DATA_PATH, 'annotation_manual.db'))
+    sunpy_cache.add('http://proba2.oma.be/lyra/data/lytaf/annotation_ppt.db',
+                    os.path.join(TEST_DATA_PATH, 'annotation_ppt.db'))
+    sunpy_cache.add('http://proba2.oma.be/lyra/data/lytaf/annotation_science.db',
+                    os.path.join(TEST_DATA_PATH, 'annotation_science.db'))
+
+
+def test_remove_lytaf_events_1(local_cache):
+    """
+    Test _remove_lytaf_events() with some artifacts found and others not.
+    """
     # Run _remove_lytaf_events
     time_test, channels_test, artifacts_status_test = \
         lyra._remove_lytaf_events(
             TIME, channels=CHANNELS, artifacts=["LAR", "Offpoint"],
-            return_artifacts=True, lytaf_path=TEST_DATA_PATH,
-            force_use_local_lytaf=True)
+            return_artifacts=True, force_use_local_lytaf=True)
     # Generated expected result
     bad_indices = np.logical_and(TIME >= LYTAF_TEST["begin_time"][0],
                                  TIME <= LYTAF_TEST["end_time"][0])
@@ -183,8 +195,7 @@ def test_remove_lytaf_events_1():
     time_test, artifacts_status_test = \
         lyra._remove_lytaf_events(
             TIME, artifacts=["LAR", "Offpoint"],
-            return_artifacts=True, lytaf_path=TEST_DATA_PATH,
-            force_use_local_lytaf=True)
+            return_artifacts=True, force_use_local_lytaf=True)
     # Assert test values are same as expected
     assert time_test.all() == time_expected.all()
     assert artifacts_status_test.keys() == artifacts_status_expected.keys()
@@ -198,15 +209,16 @@ def test_remove_lytaf_events_1():
         artifacts_status_expected["not_found"]
 
 
-def test_remove_lytaf_events_2():
-    """Test _remove_lytaf_events() with no user artifacts found."""
+def test_remove_lytaf_events_2(local_cache):
+    """
+    Test _remove_lytaf_events() with no user artifacts found.
+    """
     # Run _remove_lytaf_events
     with pytest.warns(UserWarning, match='None of user supplied artifacts were found.'):
         time_test, channels_test, artifacts_status_test = \
             lyra._remove_lytaf_events(
                 TIME, channels=CHANNELS, artifacts="Offpoint",
-                return_artifacts=True, lytaf_path=TEST_DATA_PATH,
-                force_use_local_lytaf=True)
+                return_artifacts=True, force_use_local_lytaf=True)
     # Generated expected result
     time_expected = TIME
     channels_expected = CHANNELS
@@ -233,8 +245,7 @@ def test_remove_lytaf_events_2():
     # Run _remove_lytaf_events
     with pytest.warns(UserWarning, match='None of user supplied artifacts were found.'):
         time_test, channels_test = lyra._remove_lytaf_events(
-            TIME, channels=CHANNELS, artifacts=["Offpoint"],
-            lytaf_path=TEST_DATA_PATH, force_use_local_lytaf=True)
+            TIME, channels=CHANNELS, artifacts=["Offpoint"], force_use_local_lytaf=True)
     assert np.all(time_test == time_expected)
     assert (channels_test[0]).all() == (channels_expected[0]).all()
     assert (channels_test[1]).all() == (channels_expected[1]).all()
@@ -242,37 +253,35 @@ def test_remove_lytaf_events_2():
     # Run _remove_lytaf_events
     with pytest.warns(UserWarning, match='None of user supplied artifacts were found.'):
         time_test = lyra._remove_lytaf_events(
-            TIME, artifacts=["Offpoint"],
-            lytaf_path=TEST_DATA_PATH, force_use_local_lytaf=True)
+            TIME, artifacts=["Offpoint"], force_use_local_lytaf=True)
     assert np.all(time_test == time_expected)
 
 
-def test_remove_lytaf_events_3():
-    """Test if correct errors are raised by _remove_lytaf_events()."""
+def test_remove_lytaf_events_3(local_cache):
+    """
+    Test if correct errors are raised by _remove_lytaf_events().
+    """
     with pytest.raises(TypeError):
         lyra._remove_lytaf_events(TIME, channels=6, artifacts=["LAR"],
-                                  lytaf_path=TEST_DATA_PATH,
                                   force_use_local_lytaf=True)
     with pytest.raises(ValueError):
         lyra._remove_lytaf_events(TIME,
-                                  lytaf_path=TEST_DATA_PATH,
                                   force_use_local_lytaf=True)
     with pytest.raises(TypeError):
         lyra._remove_lytaf_events(TIME, artifacts=[6],
-                                  lytaf_path=TEST_DATA_PATH,
                                   force_use_local_lytaf=True)
     with pytest.raises(ValueError):
         lyra._remove_lytaf_events(TIME,
                                   artifacts=["LAR", "incorrect artifact type"],
-                                  lytaf_path=TEST_DATA_PATH,
                                   force_use_local_lytaf=True)
 
 
-def test_get_lytaf_events():
-    """Test if LYTAF events are correctly downloaded and read in."""
+def test_get_lytaf_events(local_cache):
+    """
+    Test if LYTAF events are correctly downloaded and read in.
+    """
     # Run get_lytaf_events
     lytaf_test = lyra.get_lytaf_events("2008-01-01", "2014-01-01",
-                                       lytaf_path=TEST_DATA_PATH,
                                        force_use_local_lytaf=True)
     # Form expected result of extract_combined_lytaf
     insertion_time = [datetime.datetime.utcfromtimestamp(1371459961),
@@ -336,18 +345,21 @@ def test_get_lytaf_events():
     # are incorrectly input.
     with pytest.raises(ValueError):
         lytaf_test = lyra.get_lytaf_events("2008-01-01", "2014-01-01",
-                                           lytaf_path="test_data",
                                            combine_files=["gigo"],
                                            force_use_local_lytaf=True)
 
 
-def test_get_lytaf_event_types():
-    """Test that LYTAF event types are printed."""
-    lyra.get_lytaf_event_types(lytaf_path=TEST_DATA_PATH)
+def test_get_lytaf_event_types(local_cache):
+    """
+    Test that LYTAF event types are printed.
+    """
+    lyra.get_lytaf_event_types()
 
 
 def test_lytaf_event2string():
-    """Test _lytaf_event2string() associates correct numbers and events."""
+    """
+    Test _lytaf_event2string() associates correct numbers and events.
+    """
     out_test = lyra._lytaf_event2string(list(range(12)))
     assert out_test == ['LAR', 'N/A', 'UV occult.', 'Vis. occult.', 'Offpoint',
                         'SAA', 'Auroral zone', 'Moon in LYRA', 'Moon in SWAP',
@@ -357,7 +369,9 @@ def test_lytaf_event2string():
 
 
 def test_prep_columns():
-    """Test whether _prep_columns correctly prepares data."""
+    """
+    Test whether _prep_columns correctly prepares data.
+    """
     # Generate simple input data
     time_input = TIME[0:2]
     time_input.precision = 9
