@@ -1,7 +1,5 @@
 """SDO Map subclass definitions"""
 
-import matplotlib.pyplot as plt
-
 from astropy.coordinates import CartesianRepresentation, SkyCoord
 # Versions of Astropy that do not have HeliocentricMeanEcliptic have the same frame
 # with the misleading name HeliocentricTrueEcliptic
@@ -30,7 +28,7 @@ class AIAMap(GenericMap):
     the Sun in the following seven extreme ultraviolet bandpasses: 94 A
     (Fe XVIII), 131 A (Fe VIII, XXI), 171 A (Fe IX), 193 A (Fe XII, XXIV),
     211 A (Fe XIV), 304 A (He II), 335 A (Fe XVI). One telescope observes
-    in the visible 1600 A (C IV) and the nearby continuun (1700 A).
+    in the visible 1600 A (C IV) and the nearby continuum (1700 A).
 
     Notes
     -----
@@ -55,8 +53,8 @@ class AIAMap(GenericMap):
         # Fill in some missing info
         self.meta['detector'] = self.meta.get('detector', "AIA")
         self._nickname = self.detector
-        self.plot_settings['cmap'] = plt.get_cmap(self._get_cmap_name())
-        self.plot_settings['norm'] = ImageNormalize(stretch=source_stretch(self.meta, AsinhStretch(0.01)))
+        self.plot_settings['cmap'] = self._get_cmap_name()
+        self.plot_settings['norm'] = ImageNormalize(stretch=source_stretch(self.meta, AsinhStretch(0.01)), clip=False)
 
     @property
     def _supported_observer_coordinates(self):
@@ -78,7 +76,7 @@ class AIAMap(GenericMap):
     @classmethod
     def is_datasource_for(cls, data, header, **kwargs):
         """Determines if header corresponds to an AIA image"""
-        return header.get('instrume', '').startswith('AIA')
+        return str(header.get('instrume', '')).startswith('AIA')
 
 
 class HMIMap(GenericMap):
@@ -123,4 +121,4 @@ class HMIMap(GenericMap):
     @classmethod
     def is_datasource_for(cls, data, header, **kwargs):
         """Determines if header corresponds to an HMI image"""
-        return header.get('instrume', '').startswith('HMI')
+        return str(header.get('instrume', '')).startswith('HMI')
