@@ -97,15 +97,18 @@ def test_wcs(aia171_test_map):
 
     assert all(wcs.wcs.crpix ==
                [aia171_test_map.reference_pixel.x.value, aia171_test_map.reference_pixel.y.value])
-    assert all(wcs.wcs.cdelt == [aia171_test_map.scale.axis1.value,
-                                 aia171_test_map.scale.axis1.value])
-    assert all(
-        wcs.wcs.crval ==
-        [aia171_test_map._reference_longitude.value, aia171_test_map._reference_latitude.value])
+    assert u.allclose(wcs.wcs.cdelt * (u.Unit(wcs.wcs.cunit[0])/u.pix),
+                      u.Quantity(aia171_test_map.scale))
+    assert u.allclose(wcs.wcs.crval * u.Unit(wcs.wcs.cunit[0]),
+                      u.Quantity([aia171_test_map._reference_longitude, aia171_test_map._reference_latitude]))
     assert set(wcs.wcs.ctype) == {
         aia171_test_map.coordinate_system.axis1, aia171_test_map.coordinate_system.axis2}
     np.testing.assert_allclose(wcs.wcs.pc, aia171_test_map.rotation_matrix)
-    assert set(wcs.wcs.cunit) == {u.Unit(a) for a in aia171_test_map.spatial_units}
+
+
+def test_no_observer_wcs(heliographic_test_map):
+    assert isinstance(heliographic_test_map.wcs, astropy.wcs.WCS)
+    assert not hasattr(heliographic_test_map.wcs, "heliographic_observer")
 
 
 def test_dtype(generic_map):
@@ -199,6 +202,10 @@ def test_units(generic_map):
     generic_map.spatial_units == ('arcsec', 'arcsec')
 
 
+def test_cmap(generic_map):
+    assert generic_map.cmap == plt.get_cmap('gray')
+
+
 def test_coordinate_frame(aia171_test_map):
     frame = aia171_test_map.coordinate_frame
     assert isinstance(frame, sunpy.coordinates.Helioprojective)
@@ -564,7 +571,7 @@ def test_rotate_new_matrix(generic_map):
 
 
 def test_rotate_rmatrix_angle(generic_map):
-    with pytest.raises(ValueError):
+    with pytest.raises(TypeError):
         generic_map.rotate(angle=5, rmatrix=np.array([[1, 0], [0, 1]]))
 
 
@@ -712,3 +719,28 @@ def test_missing_metadata_warnings():
 
 def test_fits_header(aia171_test_map):
     assert isinstance(aia171_test_map.fits_header, fits.Header)
+
+
+def test_bad_coordframe_repr(generic_map):
+    generic_map.meta['CTYPE1'] = "STUART1"
+    generic_map.meta['CTYPE2'] = "STUART2"
+    assert 'Unknown' in generic_map.__repr__()
+
+
+def test_bad_header_final_fallback():
+    # Checks that if a WCS cannot be constructed from the
+    # header, a warning is raised and a simple WCS is created
+    # instead
+    header = {'cunit1': 'arcsec',
+              'cunit2': 'arcsec',
+              None: None,  # Cannot parse this into WCS
+              }
+    m = sunpy.map.GenericMap(np.zeros((10, 10)), header)
+    with pytest.warns(UserWarning,
+                      match="Unable to treat `.meta` as a FITS header, assuming a simple WCS."):
+        m.wcs
+    # Simple WCS validation
+    assert list(m.wcs.wcs.ctype) == ['HPLN-', 'HPLT-']
+    assert (m.wcs.wcs.crval == [0.0, 0.0]).all()
+    assert (m.wcs.wcs.crpix == [5.5, 5.5]).all()
+    assert (m.wcs.wcs.cdelt == [1.0, 1.0]).all()
