@@ -8,6 +8,8 @@ This module provides the `Fido
 `Fido.fetch <sunpy.net.fido_factory.UnifiedDownloaderFactory.fetch>`.
 
 """
+import os
+from pathlib import Path
 from collections.abc import Sequence
 
 from parfive import Downloader, Results
@@ -253,7 +255,7 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
 
         Examples
         --------
-        Query for LYRALightCurve data for the time range ('2012/3/4','2012/3/6')
+        Query for LYRA timeseries data for the time range ('2012/3/4','2012/3/6')
 
         >>> from sunpy.net import Fido, attrs as a
         >>> import astropy.units as u
@@ -346,6 +348,11 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
         >>> filepaths = Fido.fetch(filepaths)  # doctest: +SKIP
 
         """
+        if path is not None:
+            exists = list(filter(lambda p: p.exists(), Path(path).parents))
+            if not os.access(exists[0], os.W_OK):
+                raise PermissionError('You do not have permission to write'
+                                      f' to the directory {exists[0]}.')
 
         if "wait" in kwargs:
             raise ValueError("wait is not a valid keyword argument to Fido.fetch.")
