@@ -1,6 +1,7 @@
 import os
 import copy
 import pathlib
+from stat import S_IREAD, S_IRGRP, S_IROTH
 from unittest import mock
 
 import hypothesis.strategies as st
@@ -24,6 +25,7 @@ from sunpy.net.vso import QueryResponse as vsoQueryResponse
 from sunpy.net.vso.vso import DownloadFailed
 from sunpy.time import TimeRange, parse_time
 from sunpy.util.datatype_factory_base import MultipleMatchError
+from sunpy.tests.helpers import skip_windows
 
 TIMEFORMAT = config.get("general", "time_format")
 
@@ -62,7 +64,6 @@ def test_offline_fido(query):
 
 
 @pytest.mark.remote_data
-@pytest.mark.flaky(reruns=5)
 # Until we get more mocked, we can't really do this to online clients.
 # TODO: Hypothesis this again
 @pytest.mark.parametrize("query", [
@@ -108,7 +109,6 @@ def test_save_path(tmpdir):
 
 
 @pytest.mark.remote_data
-@pytest.mark.flaky(reruns=5)
 def test_save_path_pathlib(tmpdir):
     qr = Fido.search(a.Instrument('EVE'), a.Time("2016/10/01", "2016/10/02"), a.Level(0))
 
@@ -167,6 +167,7 @@ def test_call_error():
     assert "'UnifiedDownloaderFactory' object is not callable" in str(excinfo.value)
 
 
+@pytest.mark.remote_data
 def test_multiple_match():
     """
     Using the builtin clients a multiple match is not possible so we create a
@@ -189,11 +190,11 @@ def test_multiple_match():
 
 @pytest.mark.remote_data
 def test_fetch():
-        qr = Fido.search(a.Instrument('EVE'),
-                         a.Time("2016/10/01", "2016/10/02"),
-                         a.Level(0))
-        res = Fido.fetch(qr)
-        assert isinstance(res, Results)
+    qr = Fido.search(a.Instrument('EVE'),
+                     a.Time("2016/10/01", "2016/10/02"),
+                     a.Level(0))
+    res = Fido.fetch(qr)
+    assert isinstance(res, Results)
 
 
 """
@@ -203,6 +204,7 @@ Use LYRA here because it does not use the internet to return results.
 """
 
 
+@pytest.mark.remote_data
 def test_unifiedresponse_slicing():
     results = Fido.search(
         a.Time("2012/1/1", "2012/1/5"), a.Instrument("lyra"))
@@ -210,6 +212,7 @@ def test_unifiedresponse_slicing():
     assert isinstance(results[0], UnifiedResponse)
 
 
+@pytest.mark.remote_data
 def test_unifiedresponse_slicing_reverse():
     results = Fido.search(
         a.Time("2012/1/1", "2012/1/5"), a.Instrument("lyra"))
@@ -226,6 +229,7 @@ def test_vso_unifiedresponse():
     assert isinstance(uresp, UnifiedResponse)
 
 
+@pytest.mark.remote_data
 def test_responses():
     results = Fido.search(
         a.Time("2012/1/1", "2012/1/5"), a.Instrument("lyra"))
@@ -236,6 +240,7 @@ def test_responses():
     assert i + 1 == len(results)
 
 
+@pytest.mark.remote_data
 def test_repr():
     results = Fido.search(
         a.Time("2012/1/1", "2012/1/5"), a.Instrument("lyra"))
@@ -250,6 +255,28 @@ def filter_queries(queries):
     return attr.and_(queries) not in queries
 
 
+@pytest.mark.remote_data
+def test_path():
+    results = Fido.search(
+        a.Time("2012/1/1", "2012/1/5"), a.Instrument("lyra"))
+
+    Fido.fetch(results, path="notapath/{file}")
+
+
+@pytest.mark.remote_data
+@skip_windows
+def test_path_read_only(tmp_path):
+    results = Fido.search(
+        a.Time("2012/1/1", "2012/1/5"), a.Instrument("lyra"))
+
+    # chmod dosen't seem to work correctly on the windows CI
+    os.chmod(tmp_path, S_IREAD | S_IRGRP | S_IROTH)
+    # Check to see if it's actually read only before running the test
+    if not os.access(tmp_path, os.W_OK):
+        with pytest.raises(PermissionError):
+            Fido.fetch(results, path=tmp_path / "{file}")
+
+
 @settings(deadline=50000)
 @given(st.tuples(offline_query(), offline_query()).filter(filter_queries))
 def test_fido_indexing(queries):
@@ -383,6 +410,7 @@ def test_mixed_retry_error():
         Fido.fetch([], Results())
 
 
+@pytest.mark.remote_data
 @mock.patch("sunpy.net.dataretriever.sources.goes.XRSClient.fetch",
             return_value=["hello"])
 def test_client_fetch_wrong_type(mock_fetch):
