@@ -31,6 +31,8 @@ from sunpy.net.base_client import BaseClient
 from sunpy.util.decorators import deprecated
 from sunpy.util.exceptions import SunpyUserWarning
 
+from .zeep_plugins import SunPyLoggingZeepPlugin
+
 TIME_FORMAT = config.get("general", "time_format")
 
 DEFAULT_URL_PORT = [{'url': 'http://docs.virtualsolar.org/WSDL/VSOi_rpc_literal.wsdl',
@@ -89,24 +91,58 @@ def check_connection(url):
     try:
         return urlopen(url).getcode() == 200
     except (socket.error, socket.timeout, HTTPError, URLError) as e:
-        warnings.warn(f"Connection failed with error {e}. Retrying with different url and port.",
+        warnings.warn(f"Connection to {url} failed with error {e}. Retrying with different url and port.",
                       SunpyUserWarning)
         return None
 
 
-def get_online_vso_url(api, url, port):
-    if isinstance(api, zeep.client.Client):
-        return api
-
-    if url and check_connection(url):
-        api = zeep.Client(url, port)
-        return api
-
+def get_online_vso_url():
+    """
+    Return the first VSO url and port combination that is online.
+    """
     for mirror in DEFAULT_URL_PORT:
         if check_connection(mirror['url']):
-            api = zeep.Client(mirror['url'], port_name=mirror['port'])
-            api.set_ns_prefix('VSO', 'http://virtualsolar.org/VSO/VSOi')
-            return api
+            return mirror
+
+
+def build_client(url=None, port_name=None, **kwargs):
+    """
+    Construct a `zeep.Client` object to connect to VSO.
+
+    Parameters
+    ----------
+    url : `str`
+        The URL to connect to.
+
+    port_name : `str`
+        The "port" to use.
+
+    kwargs : `dict`
+        All extra keyword arguments are passed to `zeep.Client`.
+
+    Returns
+    -------
+
+    `zeep.Client`
+    """
+    if url is None and port_name is None:
+        mirror = get_online_vso_url()
+        if mirror is None:
+            raise ConnectionError("No online VSO mirrors could be found.")
+        url = mirror['url']
+        port_name = mirror['port']
+    elif url and port_name:
+        if not check_connection(url):
+            raise ConnectionError(f"Can't connect to url {url}")
+    else:
+        raise ValueError("Both url and port_name must be specified if either is.")
+
+    if "plugins" not in kwargs:
+        kwargs["plugins"] = [SunPyLoggingZeepPlugin()]
+
+    client = zeep.Client(url, port_name=port_name, **kwargs)
+    client.set_ns_prefix('VSO', 'http://virtualsolar.org/VSO/VSOi')
+    return client
 
 
 class QueryResponse(list):
@@ -255,16 +291,30 @@ class UnknownStatus(Exception):
 
 
 class VSOClient(BaseClient):
+    """
+    VSO Client
 
-    """ Main VSO Client. """
+    Parameters
+    ----------
+    url : `str`, optional
+        The VSO url to use. If not specified will use the first online known URL.
+
+    port : `str`, optional
+        The VSO port name to use. If not specified will use the first online known URL.
+
+    api : `zeep.Client`, optional
+        The `zeep.Client` instance to use for interacting with the VSO. If not
+        specified one will be created.
+    """
     method_order = [
         'URL-FILE_Rice', 'URL-FILE', 'URL-packaged', 'URL-TAR_GZ', 'URL-ZIP', 'URL-TAR',
     ]
 
     def __init__(self, url=None, port=None, api=None):
-        api = get_online_vso_url(api, url, port)
-        if api is None:
-            raise ConnectionError("Cannot find an online VSO mirror.")
+        if not isinstance(api, zeep.Client):
+            api = build_client(url, port)
+            if api is None:
+                raise ConnectionError("Cannot find an online VSO mirror.")
         self.api = api
 
     def make(self, atype, **kwargs):
@@ -743,7 +793,7 @@ class VSOClient(BaseClient):
                             qr[dataitem.fileiditem.fileid[0]]
                         )
                     except NoData:
-                        results.add_error('', DownloadFailed(dresponse))
+                        results.add_error('', '', DownloadFailed(dresponse))
                         continue
 
             elif code == '300' or code == '412' or code == '405':
@@ -753,7 +803,7 @@ class VSOClient(BaseClient):
                             dresponse.method.methodtype, dresponse
                         )
                     except NoData:
-                        results.add_error('', MultipleChoices(dresponse))
+                        results.add_error('', '', MultipleChoices(dresponse))
                         continue
                 elif code == '412':
                     try:
@@ -761,13 +811,13 @@ class VSOClient(BaseClient):
                             info, dresponse.info
                         )
                     except NoData:
-                        results.add_error('', MissingInformation(dresponse))
+                        results.add_error('', '', MissingInformation(dresponse))
                         continue
                 elif code == '405':
                     try:
                         methods = self.unknown_method(dresponse)
                     except NoData:
-                        results.add_error('', UnknownMethod(dresponse))
+                        results.add_error('', '', UnknownMethod(dresponse))
                         continue
 
                 files = []
@@ -783,7 +833,7 @@ class VSOClient(BaseClient):
                     qr, info
                 )
             else:
-                results.add_error(UnknownStatus(dresponse))
+                results.add_error('', '', UnknownStatus(dresponse))
 
         return results
 
