@@ -1,23 +1,23 @@
-# -*- coding: utf-8 -*-
-"""Nobeyama Radioheliograph TimeSeries subclass definitions."""
-
-from __future__ import absolute_import
-
-import datetime
-
-import pandas
-import numpy as np
-import matplotlib.pyplot as plt
+"""
+This module provies a Nobeyama Radioheliograph `~sunpy.timeseries.TimeSeries`
+source.
+"""
 from collections import OrderedDict
 
+import matplotlib as mpl
+import matplotlib.pyplot as plt
+import numpy as np
+import pandas
+
 import astropy.units as u
+from astropy.time import TimeDelta
 
 import sunpy.io
 from sunpy import config
 from sunpy.time import parse_time
-from sunpy.util.metadata import MetaDict
 from sunpy.timeseries.timeseriesbase import GenericTimeSeries
-
+from sunpy.util.metadata import MetaDict
+from sunpy.visualization import peek_show
 
 TIME_FORMAT = config.get("general", "time_format")
 
@@ -26,17 +26,15 @@ __all__ = ['NoRHTimeSeries']
 
 class NoRHTimeSeries(GenericTimeSeries):
     """
-    Nobeyama Radioheliograph Correlation Lightcurve TimeSeries.
+    Nobeyama Radioheliograph Correlation lightcurve TimeSeries.
 
-    Nobeyama Radioheliograph (NoRH) is a radio telescope dedicated to observing
-    the Sun. It consists of 84 parabolic antennas with 80 cm diameter,
+    Nobeyama Radioheliograph (NoRH) is a radio telescope dedicated to observing the Sun.
+    It consists of 84 parabolic antennas with a 80 cm diameter,
     sitting on lines of 490 m long in the east/west and of 220 m long in the north/south.
     It observes the full solar disk at 17 GHz and 34 GHz with a temporal resolution
-    down to 0.1 second resolution (typically 1 s). It is located in Japan at
-    `35.941667, 138.475833 <https://www.google.com/maps/place/Nobeyama+radio+observatory/@35.9410098,138.470243,14z/data=!4m2!3m1!1s0x0:0xe5a3821a5f6a3c4b>`_.
+    down to 0.1 second resolution (typically 1 second).
 
-    Its first observation was in April, 1992 and daily 8-hour observations are
-    available starting June, 1992.
+    Its first observation was in April, 1992 and daily 8-hour observations are available starting June, 1992.
 
     Examples
     --------
@@ -47,20 +45,20 @@ class NoRHTimeSeries(GenericTimeSeries):
 
     References
     ----------
-    * `Nobeyama Radioheliograph Homepage <http://solar.nro.nao.ac.jp/norh/>`_
-    * `Analysis Manual <http://solar.nro.nao.ac.jp/norh/doc/manuale/index.html>`_
-    * `Nobeyama Correlation Plots <http://solar.nro.nao.ac.jp/norh/html/cor_plot/>`_
+    * `Nobeyama Radioheliograph Homepage <https://solar.nro.nao.ac.jp/norh/>`_
+    * `Analysis Manual <https://solar.nro.nao.ac.jp/norh/doc/manuale/index.html>`_
+    * `Nobeyama Correlation Plots <https://solar.nro.nao.ac.jp/norh/html/cor_plot/>`_
     """
-
     # Class attribute used to specify the source class of the TimeSeries.
     _source = 'norh'
 
     def __init__(self, data, header, units, **kwargs):
-        super(NoRHTimeSeries, self).__init__(data, header, units, **kwargs)
+        super().__init__(data, header, units, **kwargs)
 
-    def peek(self, **kwargs):
+    @peek_show
+    def peek(self):
         """
-        Plots the NoRH lightcurve TimeSeries
+        Plot the NoRH lightcurve TimeSeries.
 
         .. plot::
 
@@ -68,14 +66,9 @@ class NoRHTimeSeries(GenericTimeSeries):
             import sunpy.timeseries
             norh = sunpy.timeseries.TimeSeries(sunpy.data.sample.NORH_TIMESERIES, source='NoRH')
             norh.peek()
-
-        Parameters
-        ----------
-        **kwargs : `dict`
-            Any additional plot arguments that should be used when plotting.
         """
         # Check we have a timeseries valid for plotting
-        self._validate_data_for_ploting()
+        self._validate_data_for_plotting()
 
         figure = plt.figure()
         axes = plt.gca()
@@ -89,17 +82,32 @@ class NoRHTimeSeries(GenericTimeSeries):
         axes.set_ylabel('Correlation')
         axes.legend()
 
-        figure.show()
+        return figure
+
 
     @classmethod
     def _parse_file(cls, filepath):
-        """This method parses NoRH tca and tcz correlation FITS files."""
+        """
+        This method parses NoRH FITS files.
+
+        Parameters
+        ----------
+        filepath : `str`
+            The path to the file you want to parse.
+        """
         hdus = sunpy.io.read_file(filepath)
         return cls._parse_hdus(hdus)
 
     @classmethod
     def _parse_hdus(cls, hdulist):
-        """This method parses NoRH tca and tcz correlation FITS files."""
+        """
+        This method parses a NoRH `astropy.io.fits.HDUList`.
+
+        Parameters
+        ----------
+        hdulist : `astropy.io.fits.HDUList`
+            A HDU list.
+        """
         header = MetaDict(OrderedDict(hdulist[0].header))
         # For these NoRH files, the time series data is recorded in the primary
         # HDU
@@ -112,9 +120,9 @@ class NoRHTimeSeries(GenericTimeSeries):
         cadence = np.float(header['CDELT1'])
         sec_array = np.linspace(0, length - 1, int(length / cadence))
 
-        norh_time = []
-        for s in sec_array:
-            norh_time.append(obs_start_time + datetime.timedelta(0, s))
+        norh_time = obs_start_time + TimeDelta(sec_array*u.second)
+        norh_time.precision = 9
+        norh_time = norh_time.isot.astype('datetime64')
 
         # Add the units data
         units = OrderedDict([('Correlation Coefficient', u.dimensionless_unscaled)])
@@ -124,7 +132,10 @@ class NoRHTimeSeries(GenericTimeSeries):
 
     @classmethod
     def is_datasource_for(cls, **kwargs):
-        """Determines if header corresponds to a Nobeyama Radioheliograph Correlation lightcurve"""
+        """
+        Determines if header corresponds to a Nobeyama Radioheliograph
+        Correlation `~sunpy.timeseries.TimeSeries`.
+        """
         if 'source' in kwargs.keys():
             if kwargs.get('source', ''):
                 return kwargs.get('source', '').lower().startswith(cls._source)
