@@ -44,7 +44,17 @@ def deprecated(since, message='', name='', alternative=''):
         place of the deprecated object. The deprecation warning will
         tell the user about this alternative if provided.
     """
-
+    since_major, since_minor = since.split('.')[:2]
+    since_lts = since_minor == 0
+    if since_lts:
+        major = int(since_major)
+        minor = int(since_minor) + 1
+    else:
+        major = int(since_major) + 1
+        minor = 1
+    removal_version = f"{major}.{minor}"
+    message += f" This is scheduled for removal in {removal_version}."
+    
     method_types = (classmethod, staticmethod, types.MethodType)
 
     def deprecate_doc(old_doc, message):
@@ -56,7 +66,7 @@ def deprecated(since, message='', name='', alternative=''):
         old_doc = textwrap.dedent(old_doc).strip('\n')
         new_doc = (('\n.. deprecated:: {since}'
                     '\n    {message}\n\n'.format(
-                     **{'since': since, 'message': message.strip()})) + old_doc)
+                        **{'since': since, 'message': message.strip()})) + old_doc)
         if not old_doc:
             # This is to prevent a spurious 'unexpected unindent' warning from
             # docutils when the original docstring was blank.
@@ -81,7 +91,7 @@ def deprecated(since, message='', name='', alternative=''):
         if isinstance(func, method_types):
             func_wrapper = type(func)
         else:
-            func_wrapper = lambda f: f  # noqa
+            def func_wrapper(f): return f  # noqa
 
         func = get_function(func)
 
